==> box64_0.2.2%2Bdfsg.orig.tar.xz: box64-0.2.2/src/wrapped/wrappedlibxcbrender_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

//GO(xcb_render_add_glyphs, 
//GO(xcb_render_add_glyphs_checked, 
//GO(xcb_render_add_glyphs_data, 
//GO(xcb_render_add_glyphs_data_end, 
//GO(xcb_render_add_glyphs_data_length, 
//GO(xcb_render_add_glyphs_glyphids, 
//GO(xcb_render_add_glyphs_glyphids_end, 
//GO(xcb_render_add_glyphs_glyphids_length, 
//GO(xcb_render_add_glyphs_glyphs, 
//GO(xcb_render_add_glyphs_glyphs_iterator, 
//GO(xcb_render_add_glyphs_glyphs_length, 
//GO(xcb_render_add_glyphs_sizeof, 
//GO(xcb_render_add_traps, 
//GO(xcb_render_add_traps_checked, 
//GO(xcb_render_add_traps_sizeof, 
//GO(xcb_render_add_traps_traps, 
//GO(xcb_render_add_traps_traps_iterator, 
//GO(xcb_render_add_traps_traps_length, 
//GO(xcb_render_animcursorelt_end, 
//GO(xcb_render_animcursorelt_next, 
//GO(xcb_render_change_picture, 
//GO(xcb_render_change_picture_aux, 
//GO(xcb_render_change_picture_aux_checked, 
//GO(xcb_render_change_picture_checked, 
//GO(xcb_render_change_picture_sizeof, 
//GO(xcb_render_change_picture_value_list, 
//GO(xcb_render_change_picture_value_list_serialize, 
//GO(xcb_render_change_picture_value_list_sizeof, 
//GO(xcb_render_change_picture_value_list_unpack, 
//GO(xcb_render_color_end, 
//GO(xcb_render_color_next, 
GO(xcb_render_composite, pFppCpppwwwwwwWW)
//GO(xcb_render_composite_checked, 
//GO(xcb_render_composite_glyphs_16, 
//GO(xcb_render_composite_glyphs_16_checked, 
//GO(xcb_render_composite_glyphs_16_glyphcmds, 
//GO(xcb_render_composite_glyphs_16_glyphcmds_end, 
//GO(xcb_render_composite_glyphs_16_glyphcmds_length, 
//GO(xcb_render_composite_glyphs_16_sizeof, 
//GO(xcb_render_composite_glyphs_32, 
//GO(xcb_render_composite_glyphs_32_checked, 
//GO(xcb_render_composite_glyphs_32_glyphcmds, 
//GO(xcb_render_composite_glyphs_32_glyphcmds_end, 
//GO(xcb_render_composite_glyphs_32_glyphcmds_length, 
//GO(xcb_render_composite_glyphs_32_sizeof, 
//GO(xcb_render_composite_glyphs_8, 
//GO(xcb_render_composite_glyphs_8_checked, 
//GO(xcb_render_composite_glyphs_8_glyphcmds, 
//GO(xcb_render_composite_glyphs_8_glyphcmds_end, 
//GO(xcb_render_composite_glyphs_8_glyphcmds_length, 
//GO(xcb_render_composite_glyphs_8_sizeof, 
//GO(xcb_render_create_anim_cursor, 
//GO(xcb_render_create_anim_cursor_checked, 
//GO(xcb_render_create_anim_cursor_cursors, 
//GO(xcb_render_create_anim_cursor_cursors_iterator, 
//GO(xcb_render_create_anim_cursor_cursors_length, 
//GO(xcb_render_create_anim_cursor_sizeof, 
//GO(xcb_render_create_conical_gradient, 
//GO(xcb_render_create_conical_gradient_checked, 
//GO(xcb_render_create_conical_gradient_colors, 
//GO(xcb_render_create_conical_gradient_colors_iterator, 
//GO(xcb_render_create_conical_gradient_colors_length, 
//GO(xcb_render_create_conical_gradient_sizeof, 
//GO(xcb_render_create_conical_gradient_stops, 
//GO(xcb_render_create_conical_gradient_stops_end, 
//GO(xcb_render_create_conical_gradient_stops_length, 
GO(xcb_render_create_cursor, pFppppWW)
GO(xcb_render_create_cursor_checked, pFppppWW)
//GO(xcb_render_create_glyph_set, 
//GO(xcb_render_create_glyph_set_checked, 
//GO(xcb_render_create_linear_gradient, 
//GO(xcb_render_create_linear_gradient_checked, 
//GO(xcb_render_create_linear_gradient_colors, 
//GO(xcb_render_create_linear_gradient_colors_iterator, 
//GO(xcb_render_create_linear_gradient_colors_length, 
//GO(xcb_render_create_linear_gradient_sizeof, 
//GO(xcb_render_create_linear_gradient_stops, 
//GO(xcb_render_create_linear_gradient_stops_end, 
//GO(xcb_render_create_linear_gradient_stops_length, 
GO(xcb_render_create_picture, pFpppiup)
//GO(xcb_render_create_picture_aux, 
//GO(xcb_render_create_picture_aux_checked, 
GO(xcb_render_create_picture_checked, pFpppiup)
//GO(xcb_render_create_picture_sizeof, 
//GO(xcb_render_create_picture_value_list, 
//GO(xcb_render_create_picture_value_list_serialize, 
//GO(xcb_render_create_picture_value_list_sizeof, 
//GO(xcb_render_create_picture_value_list_unpack, 
//GO(xcb_render_create_radial_gradient, 
//GO(xcb_render_create_radial_gradient_checked, 
//GO(xcb_render_create_radial_gradient_colors, 
//GO(xcb_render_create_radial_gradient_colors_iterator, 
//GO(xcb_render_create_radial_gradient_colors_length, 
//GO(xcb_render_create_radial_gradient_sizeof, 
//GO(xcb_render_create_radial_gradient_stops, 
//GO(xcb_render_create_radial_gradient_stops_end, 
//GO(xcb_render_create_radial_gradient_stops_length, 
//GO(xcb_render_create_solid_fill, 
//GO(xcb_render_create_solid_fill_checked, 
//GO(xcb_render_directformat_end, 
//GO(xcb_render_directformat_next, 
//GO(xcb_render_fill_rectangles, 
//GO(xcb_render_fill_rectangles_checked, 
//GO(xcb_render_fill_rectangles_rects, 
//GO(xcb_render_fill_rectangles_rects_iterator, 
//GO(xcb_render_fill_rectangles_rects_length, 
//GO(xcb_render_fill_rectangles_sizeof, 
//GO(xcb_render_fixed_end, 
//GO(xcb_render_fixed_next, 
//GO(xcb_render_free_glyphs, 
//GO(xcb_render_free_glyphs_checked, 
//GO(xcb_render_free_glyph_set, 
//GO(xcb_render_free_glyph_set_checked, 
//GO(xcb_render_free_glyphs_glyphs, 
//GO(xcb_render_free_glyphs_glyphs_end, 
//GO(xcb_render_free_glyphs_glyphs_length, 
//GO(xcb_render_free_glyphs_sizeof, 
GO(xcb_render_free_picture, pFppp)
//GO(xcb_render_free_picture_checked, 
//GO(xcb_render_glyph_end, 
//GO(xcb_render_glyphinfo_end, 
//GO(xcb_render_glyphinfo_next, 
//GO(xcb_render_glyph_next, 
//GO(xcb_render_glyphset_end, 
//GO(xcb_render_glyphset_next, 
DATA(xcb_render_id, 2*sizeof(void*))
//GO(xcb_render_indexvalue_end, 
//GO(xcb_render_indexvalue_next, 
//GO(xcb_render_linefix_end, 
//GO(xcb_render_linefix_next, 
//GO(xcb_render_pictdepth_end, 
//GO(xcb_render_pictdepth_next, 
//GO(xcb_render_pictdepth_sizeof, 
//GO(xcb_render_pictdepth_visuals, 
//GO(xcb_render_pictdepth_visuals_iterator, 
//GO(xcb_render_pictdepth_visuals_length, 
//GO(xcb_render_pictformat_end, 
//GO(xcb_render_pictformat_next, 
//GO(xcb_render_pictforminfo_end, 
//GO(xcb_render_pictforminfo_next, 
//GO(xcb_render_pictscreen_depths_iterator, 
//GO(xcb_render_pictscreen_depths_length, 
//GO(xcb_render_pictscreen_end, 
//GO(xcb_render_pictscreen_next, 
//GO(xcb_render_pictscreen_sizeof, 
//GO(xcb_render_picture_end, 
//GO(xcb_render_picture_next, 
//GO(xcb_render_pictvisual_end, 
//GO(xcb_render_pictvisual_next, 
//GO(xcb_render_pointfix_end, 
//GO(xcb_render_pointfix_next, 
//GO(xcb_render_query_filters, 
//GO(xcb_render_query_filters_aliases, 
//GO(xcb_render_query_filters_aliases_end, 
//GO(xcb_render_query_filters_aliases_length, 
//GO(xcb_render_query_filters_filters_iterator, 
//GO(xcb_render_query_filters_filters_length, 
//GO(xcb_render_query_filters_reply, 
//GO(xcb_render_query_filters_sizeof, 
//GO(xcb_render_query_filters_unchecked, 
GO(xcb_render_query_pict_formats, pFpp)
//GO(xcb_render_query_pict_formats_formats, 
//GO(xcb_render_query_pict_formats_formats_iterator, 
//GO(xcb_render_query_pict_formats_formats_length, 
GO(xcb_render_query_pict_formats_reply, pFpup)
//GO(xcb_render_query_pict_formats_screens_iterator, 
//GO(xcb_render_query_pict_formats_screens_length, 
//GO(xcb_render_query_pict_formats_sizeof, 
//GO(xcb_render_query_pict_formats_subpixels, 
//GO(xcb_render_query_pict_formats_subpixels_end, 
//GO(xcb_render_query_pict_formats_subpixels_length, 
//GO(xcb_render_query_pict_formats_unchecked, 
//GO(xcb_render_query_pict_index_values, 
//GO(xcb_render_query_pict_index_values_reply, 
//GO(xcb_render_query_pict_index_values_sizeof, 
//GO(xcb_render_query_pict_index_values_unchecked, 
//GO(xcb_render_query_pict_index_values_values, 
//GO(xcb_render_query_pict_index_values_values_iterator, 
//GO(xcb_render_query_pict_index_values_values_length, 
GO(xcb_render_query_version, pFppuu)
GO(xcb_render_query_version_reply, pFpup)
GO(xcb_render_query_version_unchecked, pFppuu)
//GO(xcb_render_reference_glyph_set, 
//GO(xcb_render_reference_glyph_set_checked, 
//GO(xcb_render_set_picture_clip_rectangles, 
//GO(xcb_render_set_picture_clip_rectangles_checked, 
//GO(xcb_render_set_picture_clip_rectangles_rectangles, 
//GO(xcb_render_set_picture_clip_rectangles_rectangles_iterator, 
//GO(xcb_render_set_picture_clip_rectangles_rectangles_length, 
//GO(xcb_render_set_picture_clip_rectangles_sizeof, 
//GO(xcb_render_set_picture_filter, 
//GO(xcb_render_set_picture_filter_checked, 
//GO(xcb_render_set_picture_filter_filter, 
//GO(xcb_render_set_picture_filter_filter_end, 
//GO(xcb_render_set_picture_filter_filter_length, 
//GO(xcb_render_set_picture_filter_sizeof, 
//GO(xcb_render_set_picture_filter_values, 
//GO(xcb_render_set_picture_filter_values_end, 
//GO(xcb_render_set_picture_filter_values_length, 
//GO(xcb_render_set_picture_transform, 
//GO(xcb_render_set_picture_transform_checked, 
//GO(xcb_render_spanfix_end, 
//GO(xcb_render_spanfix_next, 
//GO(xcb_render_transform_end, 
//GO(xcb_render_transform_next, 
//GO(xcb_render_trap_end, 
//GO(xcb_render_trapezoid_end, 
//GO(xcb_render_trapezoid_next, 
//GO(xcb_render_trapezoids, 
//GO(xcb_render_trapezoids_checked, 
//GO(xcb_render_trapezoids_sizeof, 
//GO(xcb_render_trapezoids_traps, 
//GO(xcb_render_trapezoids_traps_iterator, 
//GO(xcb_render_trapezoids_traps_length, 
//GO(xcb_render_trap_next, 
//GO(xcb_render_triangle_end, 
//GO(xcb_render_triangle_next, 
//GO(xcb_render_triangles, 
//GO(xcb_render_triangles_checked, 
//GO(xcb_render_triangles_sizeof, 
//GO(xcb_render_triangles_triangles, 
//GO(xcb_render_triangles_triangles_iterator, 
//GO(xcb_render_triangles_triangles_length, 
//GO(xcb_render_tri_fan, 
//GO(xcb_render_tri_fan_checked, 
//GO(xcb_render_tri_fan_points, 
//GO(xcb_render_tri_fan_points_iterator, 
//GO(xcb_render_tri_fan_points_length, 
//GO(xcb_render_tri_fan_sizeof, 
//GO(xcb_render_tri_strip, 
//GO(xcb_render_tri_strip_checked, 
//GO(xcb_render_tri_strip_points, 
//GO(xcb_render_tri_strip_points_iterator, 
//GO(xcb_render_tri_strip_points_length, 
//GO(xcb_render_tri_strip_sizeof,

==> box64_0.3.4%2Bdfsg.orig.tar.xz: box64-0.3.4/src/wrapped/wrappedlibxcbrender_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

//GO(xcb_render_add_glyphs, 
//GO(xcb_render_add_glyphs_checked, 
//GO(xcb_render_add_glyphs_data, 
//GO(xcb_render_add_glyphs_data_end, 
//GO(xcb_render_add_glyphs_data_length, 
//GO(xcb_render_add_glyphs_glyphids, 
//GO(xcb_render_add_glyphs_glyphids_end, 
//GO(xcb_render_add_glyphs_glyphids_length, 
//GO(xcb_render_add_glyphs_glyphs, 
//GO(xcb_render_add_glyphs_glyphs_iterator, 
//GO(xcb_render_add_glyphs_glyphs_length, 
//GO(xcb_render_add_glyphs_sizeof, 
//GO(xcb_render_add_traps, 
//GO(xcb_render_add_traps_checked, 
//GO(xcb_render_add_traps_sizeof, 
//GO(xcb_render_add_traps_traps, 
//GO(xcb_render_add_traps_traps_iterator, 
//GO(xcb_render_add_traps_traps_length, 
//GO(xcb_render_animcursorelt_end, 
//GO(xcb_render_animcursorelt_next, 
//GO(xcb_render_change_picture, 
//GO(xcb_render_change_picture_aux, 
//GO(xcb_render_change_picture_aux_checked, 
//GO(xcb_render_change_picture_checked, 
//GO(xcb_render_change_picture_sizeof, 
//GO(xcb_render_change_picture_value_list, 
//GO(xcb_render_change_picture_value_list_serialize, 
//GO(xcb_render_change_picture_value_list_sizeof, 
//GO(xcb_render_change_picture_value_list_unpack, 
//GO(xcb_render_color_end, 
//GO(xcb_render_color_next, 
GO(xcb_render_composite, pFbpCpppwwwwwwWW)
//GO(xcb_render_composite_checked, 
//GO(xcb_render_composite_glyphs_16, 
//GO(xcb_render_composite_glyphs_16_checked, 
//GO(xcb_render_composite_glyphs_16_glyphcmds, 
//GO(xcb_render_composite_glyphs_16_glyphcmds_end, 
//GO(xcb_render_composite_glyphs_16_glyphcmds_length, 
//GO(xcb_render_composite_glyphs_16_sizeof, 
//GO(xcb_render_composite_glyphs_32, 
//GO(xcb_render_composite_glyphs_32_checked, 
//GO(xcb_render_composite_glyphs_32_glyphcmds, 
//GO(xcb_render_composite_glyphs_32_glyphcmds_end, 
//GO(xcb_render_composite_glyphs_32_glyphcmds_length, 
//GO(xcb_render_composite_glyphs_32_sizeof, 
//GO(xcb_render_composite_glyphs_8, 
//GO(xcb_render_composite_glyphs_8_checked, 
//GO(xcb_render_composite_glyphs_8_glyphcmds, 
//GO(xcb_render_composite_glyphs_8_glyphcmds_end, 
//GO(xcb_render_composite_glyphs_8_glyphcmds_length, 
//GO(xcb_render_composite_glyphs_8_sizeof, 
GO(xcb_render_create_anim_cursor, pFbpup)
GO(xcb_render_create_anim_cursor_checked, pFbpup)
//GO(xcb_render_create_anim_cursor_cursors, 
//GO(xcb_render_create_anim_cursor_cursors_iterator, 
//GO(xcb_render_create_anim_cursor_cursors_length, 
//GO(xcb_render_create_anim_cursor_sizeof, 
//GO(xcb_render_create_conical_gradient, 
//GO(xcb_render_create_conical_gradient_checked, 
//GO(xcb_render_create_conical_gradient_colors, 
//GO(xcb_render_create_conical_gradient_colors_iterator, 
//GO(xcb_render_create_conical_gradient_colors_length, 
//GO(xcb_render_create_conical_gradient_sizeof, 
//GO(xcb_render_create_conical_gradient_stops, 
//GO(xcb_render_create_conical_gradient_stops_end, 
//GO(xcb_render_create_conical_gradient_stops_length, 
GO(xcb_render_create_cursor, uFbuuWW)
GO(xcb_render_create_cursor_checked, uFbuuWW)
//GO(xcb_render_create_glyph_set, 
//GO(xcb_render_create_glyph_set_checked, 
//GO(xcb_render_create_linear_gradient, 
//GO(xcb_render_create_linear_gradient_checked, 
//GO(xcb_render_create_linear_gradient_colors, 
//GO(xcb_render_create_linear_gradient_colors_iterator, 
//GO(xcb_render_create_linear_gradient_colors_length, 
//GO(xcb_render_create_linear_gradient_sizeof, 
//GO(xcb_render_create_linear_gradient_stops, 
//GO(xcb_render_create_linear_gradient_stops_end, 
//GO(xcb_render_create_linear_gradient_stops_length, 
GO(xcb_render_create_picture, uFbuuiup)
//GO(xcb_render_create_picture_aux, 
//GO(xcb_render_create_picture_aux_checked, 
GO(xcb_render_create_picture_checked, uFbuuiup)
//GO(xcb_render_create_picture_sizeof, 
//GO(xcb_render_create_picture_value_list, 
//GO(xcb_render_create_picture_value_list_serialize, 
//GO(xcb_render_create_picture_value_list_sizeof, 
//GO(xcb_render_create_picture_value_list_unpack, 
//GO(xcb_render_create_radial_gradient, 
//GO(xcb_render_create_radial_gradient_checked, 
//GO(xcb_render_create_radial_gradient_colors, 
//GO(xcb_render_create_radial_gradient_colors_iterator, 
//GO(xcb_render_create_radial_gradient_colors_length, 
//GO(xcb_render_create_radial_gradient_sizeof, 
//GO(xcb_render_create_radial_gradient_stops, 
//GO(xcb_render_create_radial_gradient_stops_end, 
//GO(xcb_render_create_radial_gradient_stops_length, 
//GO(xcb_render_create_solid_fill, 
//GO(xcb_render_create_solid_fill_checked, 
//GO(xcb_render_directformat_end, 
//GO(xcb_render_directformat_next, 
//GO(xcb_render_fill_rectangles, 
//GO(xcb_render_fill_rectangles_checked, 
//GO(xcb_render_fill_rectangles_rects, 
//GO(xcb_render_fill_rectangles_rects_iterator, 
//GO(xcb_render_fill_rectangles_rects_length, 
//GO(xcb_render_fill_rectangles_sizeof, 
//GO(xcb_render_fixed_end, 
//GO(xcb_render_fixed_next, 
//GO(xcb_render_free_glyphs, 
//GO(xcb_render_free_glyphs_checked, 
//GO(xcb_render_free_glyph_set, 
//GO(xcb_render_free_glyph_set_checked, 
//GO(xcb_render_free_glyphs_glyphs, 
//GO(xcb_render_free_glyphs_glyphs_end, 
//GO(xcb_render_free_glyphs_glyphs_length, 
//GO(xcb_render_free_glyphs_sizeof, 
GO(xcb_render_free_picture, uFbu)
GO(xcb_render_free_picture_checked, fFbu)
//GO(xcb_render_glyph_end, 
//GO(xcb_render_glyphinfo_end, 
//GO(xcb_render_glyphinfo_next, 
//GO(xcb_render_glyph_next, 
//GO(xcb_render_glyphset_end, 
//GO(xcb_render_glyphset_next, 
DATA(xcb_render_id, 2*sizeof(void*))
//GO(xcb_render_indexvalue_end, 
//GO(xcb_render_indexvalue_next, 
//GO(xcb_render_linefix_end, 
//GO(xcb_render_linefix_next, 
//GO(xcb_render_pictdepth_end, 
//GO(xcb_render_pictdepth_next, 
//GO(xcb_render_pictdepth_sizeof, 
//GO(xcb_render_pictdepth_visuals, 
//GO(xcb_render_pictdepth_visuals_iterator, 
//GO(xcb_render_pictdepth_visuals_length, 
//GO(xcb_render_pictformat_end, 
//GO(xcb_render_pictformat_next, 
//GO(xcb_render_pictforminfo_end, 
//GO(xcb_render_pictforminfo_next, 
//GO(xcb_render_pictscreen_depths_iterator, 
//GO(xcb_render_pictscreen_depths_length, 
//GO(xcb_render_pictscreen_end, 
//GO(xcb_render_pictscreen_next, 
//GO(xcb_render_pictscreen_sizeof, 
//GO(xcb_render_picture_end, 
//GO(xcb_render_picture_next, 
//GO(xcb_render_pictvisual_end, 
//GO(xcb_render_pictvisual_next, 
//GO(xcb_render_pointfix_end, 
//GO(xcb_render_pointfix_next, 
//GO(xcb_render_query_filters, 
//GO(xcb_render_query_filters_aliases, 
//GO(xcb_render_query_filters_aliases_end, 
//GO(xcb_render_query_filters_aliases_length, 
//GO(xcb_render_query_filters_filters_iterator, 
//GO(xcb_render_query_filters_filters_length, 
//GO(xcb_render_query_filters_reply, 
//GO(xcb_render_query_filters_sizeof, 
//GO(xcb_render_query_filters_unchecked, 
GO(xcb_render_query_pict_formats, uFbu)
//GO(xcb_render_query_pict_formats_formats, 
//GO(xcb_render_query_pict_formats_formats_iterator, 
//GO(xcb_render_query_pict_formats_formats_length, 
GO(xcb_render_query_pict_formats_reply, pFbup)
//GO(xcb_render_query_pict_formats_screens_iterator, 
//GO(xcb_render_query_pict_formats_screens_length, 
//GO(xcb_render_query_pict_formats_sizeof, 
//GO(xcb_render_query_pict_formats_subpixels, 
//GO(xcb_render_query_pict_formats_subpixels_end, 
//GO(xcb_render_query_pict_formats_subpixels_length, 
//GO(xcb_render_query_pict_formats_unchecked, 
//GO(xcb_render_query_pict_index_values, 
//GO(xcb_render_query_pict_index_values_reply, 
//GO(xcb_render_query_pict_index_values_sizeof, 
//GO(xcb_render_query_pict_index_values_unchecked, 
//GO(xcb_render_query_pict_index_values_values, 
//GO(xcb_render_query_pict_index_values_values_iterator, 
//GO(xcb_render_query_pict_index_values_values_length, 
GO(xcb_render_query_version, uFbuu)
GO(xcb_render_query_version_reply, pFbup)
GO(xcb_render_query_version_unchecked, uFbuu)
//GO(xcb_render_reference_glyph_set, 
//GO(xcb_render_reference_glyph_set_checked, 
//GO(xcb_render_set_picture_clip_rectangles, 
//GO(xcb_render_set_picture_clip_rectangles_checked, 
//GO(xcb_render_set_picture_clip_rectangles_rectangles, 
//GO(xcb_render_set_picture_clip_rectangles_rectangles_iterator, 
//GO(xcb_render_set_picture_clip_rectangles_rectangles_length, 
//GO(xcb_render_set_picture_clip_rectangles_sizeof, 
//GO(xcb_render_set_picture_filter, 
//GO(xcb_render_set_picture_filter_checked, 
//GO(xcb_render_set_picture_filter_filter, 
//GO(xcb_render_set_picture_filter_filter_end, 
//GO(xcb_render_set_picture_filter_filter_length, 
//GO(xcb_render_set_picture_filter_sizeof, 
//GO(xcb_render_set_picture_filter_values, 
//GO(xcb_render_set_picture_filter_values_end, 
//GO(xcb_render_set_picture_filter_values_length, 
//GO(xcb_render_set_picture_transform, 
//GO(xcb_render_set_picture_transform_checked, 
//GO(xcb_render_spanfix_end, 
//GO(xcb_render_spanfix_next, 
//GO(xcb_render_transform_end, 
//GO(xcb_render_transform_next, 
//GO(xcb_render_trap_end, 
//GO(xcb_render_trapezoid_end, 
//GO(xcb_render_trapezoid_next, 
//GO(xcb_render_trapezoids, 
//GO(xcb_render_trapezoids_checked, 
//GO(xcb_render_trapezoids_sizeof, 
//GO(xcb_render_trapezoids_traps, 
//GO(xcb_render_trapezoids_traps_iterator, 
//GO(xcb_render_trapezoids_traps_length, 
//GO(xcb_render_trap_next, 
//GO(xcb_render_triangle_end, 
//GO(xcb_render_triangle_next, 
//GO(xcb_render_triangles, 
//GO(xcb_render_triangles_checked, 
//GO(xcb_render_triangles_sizeof, 
//GO(xcb_render_triangles_triangles, 
//GO(xcb_render_triangles_triangles_iterator, 
//GO(xcb_render_triangles_triangles_length, 
//GO(xcb_render_tri_fan, 
//GO(xcb_render_tri_fan_checked, 
//GO(xcb_render_tri_fan_points, 
//GO(xcb_render_tri_fan_points_iterator, 
//GO(xcb_render_tri_fan_points_length, 
//GO(xcb_render_tri_fan_sizeof, 
//GO(xcb_render_tri_strip, 
//GO(xcb_render_tri_strip_checked, 
//GO(xcb_render_tri_strip_points, 
//GO(xcb_render_tri_strip_points_iterator, 
//GO(xcb_render_tri_strip_points_length, 
//GO(xcb_render_tri_strip_sizeof,
